Base schema: http://purl.allotrope.org/json-schemas/adm/light-obscuration/REC/2021/12/light-obscuration.schema

Changes:
- Reasoning: Revised format of the schema to follow the hierachical pattern introduced in ASM core schema
- Proposal: Request revision of Allotrope schema to this format AND/OR incorporate light-obscuration into solution analyzer schema

- Added `light obscuration aggregate document`

  - Reasoning: TODO
  - Proposal: TODO

- Added `data system document` to `light obscuration aggregate document`

  - Reasoning: TODO
  - Proposal: TODO

- Added `device system document` to `light obscuration aggregate document`

  - Reasoning: TODO
  - Proposal: TODO

- Added `device document` to `device system document`

  - Reasoning: TODO
  - Proposal: TODO

- Added `light obscuration document` to `light obscuration aggregate document`

  - Reasoning: TODO
  - Proposal: TODO

- Added `measurement aggregate document` to `light obscuration document`

  - Reasoning: TODO
  - Proposal: TODO

- Added `measurement document` to `measurement aggregate document`

  - Reasoning: TODO
  - Proposal: TODO

- Added `device control aggregate document` to `measurement document`

  - Reasoning: TODO
  - Proposal: TODO

- Added `device control document` to `device control aggregate document`

  - Reasoning: TODO
  - Proposal: TODO

- Added `device control document item` to `device control document`

  - Reasoning: TODO
  - Proposal: TODO

- Added `sample document` to `measurement document`

  - Reasoning: TODO
  - Proposal: TODO

- Added `processed data aggregate document` to `measurement document`

  - Reasoning: TODO
  - Proposal: TODO

- Added `processed data document` to `measurement document`

  - Reasoning: TODO
  - Proposal: TODO

- Added `calculated data aggregate document` to `light obscuration aggregate document`

  - Reasoning: TODO
  - Proposal: TODO

- Added `calculated data document` to `calculated data aggregate document`

  - Reasoning: TODO
  - Proposal: TODO

- Added `data source aggregate document` to `calculated data document`

  - Reasoning: TODO
  - Proposal: TODO

- Added `data source document` to `data source aggregate document`

  - Reasoning: TODO
  - Proposal: TODO

- Added `distribution identifier` to `distibution`

  - Reasoning: TODO
  - Proposal: TODO

- Moved `analyst` property to `measurement aggregate document`

  - Reasoning: TODO
  - Proposal: TODO

- Moved `measurement document` to `measurement aggregate document`

  - Reasoning: TODO
  - Proposal: TODO

- Moved `measurement identifier` property to `measurement document`

  - Reasoning: TODO
  - Proposal: TODO

- Moved `distribution document` to `distribution aggregate document`

  - Reasoning: TODO
  - Proposal: TODO

- Moed `detector view volume` property to `device control document item`

  - Reasoning: TODO
  - Proposal: TODO

- Moved `detector view volume` property to `device control document item`

  - Reasoning: TODO
  - Proposal: TODO

- Moved `flush volume setting` property to `device control document item`

  - Reasoning: TODO
  - Proposal: TODO

- Moved `repetition setting` property to to `device control document item`

  - Reasoning: TODO
  - Proposal: TODO

- Moved `sample volume setting` property to `device control document item`

  - Reasoning: TODO
  - Proposal: TODO

- Moved `dilution factor setting` property to `data processing document`

  - Reasoning: TODO
  - Proposal: TODO

- Moved `sample identifier` property to `sample document`

  - Reasoning: TODO
  - Proposal: TODO

- Moved `detector identifier` property to `device document`

  - Reasoning: TODO
  - Proposal: TODO

- Moved `detector model number` property to `device document`

  - Reasoning: TODO
  - Proposal: TODO

- Moved `equipment serial number` property to `light obscuration aggregate document`

  - Reasoning: TODO
  - Proposal: TODO

- Moved `model number` property to `light obscuration aggregate document`

  - Reasoning: TODO
  - Proposal: TODO

- Moved `measurement time` property to `measurement document`

  - Reasoning: TODO
  - Proposal: TODO

- Removed `differential particle density` and `differential count` from required properties of `distribution`
  - Reasoning: TODO
  - Proposal: TODO
